@@ -1,11 +1,11 @@
 #' Argument assertions (Experimental)
 #'
 # -------------------------------------------------------------------------
-#' Assertions for function arguments. Motivated by [vctrs::vec_assert()] but
-#' with lower overhead at a cost of less informative error messages. Designed to
-#' make it easy to identify the top level calling function whether used within a
-#' user facing function or internally. They are somewhat experimental in nature
-#' and should be treated accordingly.
+#' Assertions for function arguments. Motivated by assertions from the vctrs
+#' package but with lower overhead at a cost of less informative error messages.
+#' Designed to make it easy to identify the top level calling function whether
+#' used within a user facing function or internally. They are somewhat
+#' experimental in nature and should be treated accordingly.
 #'
 # -------------------------------------------------------------------------
 #' @param x
@@ -45,8 +45,7 @@
 #'
 #' If the assertion succeeds then the input is returned invisibly.
 #'
-#' Otherwise an error of class "ympes-error" (with optional subclass if supplied
-#' when calling the assertion).
+#' Otherwise and erro (with optional subclass if supplied when calling).
 #'
 # -------------------------------------------------------------------------
 #' @examples
@@ -1017,8 +1016,7 @@ assert_between <- function(
 # -------------------------------------------------------------------------
 
 .stopf <- function(msg, .call = sys.call(-1L), .subclass = NULL) {
-    class <- c(.subclass, "ympes-error")
     call <- .call[1L]
-    err <- errorCondition(msg, class = class, call = call)
+    err <- errorCondition(msg, class = .subclass, call = call)
     stop(err)
 }
